@@ -9,8 +9,9 @@ class requestMode(object):  # ff
     delete = "delete"
 
 
-def sendRequest(url, header, params="", content="",
-                rMode=requestMode.post):
+def sendRequest(
+    url, header="", params="", content="", rMode=requestMode.post, files=""
+):
 
     if rMode == "post":
         rMode = requests.post
@@ -22,12 +23,18 @@ def sendRequest(url, header, params="", content="",
         rMode = requests.delete
 
     status = True
+
+    content = (
+        json.dumps(content) if isinstance(content, (list, dict)) else content
+    )
+
     try:
         response = rMode(
             url=url,
             headers=header,
             params=params,
-            data=json.dumps(content)
+            files=files,
+            data=content,
         )
         if response.status_code < 300 and response.status_code >= 200:
             status = True
@@ -39,4 +46,4 @@ def sendRequest(url, header, params="", content="",
         status = False
         content = '%s Request failed' % url
 
-    return(status, content)
+    return (status, content)
