@@ -97,10 +97,10 @@ class dPrint(object):
 
         if timeType == "ms":
             dateTime = datetime.datetime.fromtimestamp(time.time()).strftime(
-                "%y-%M-%d %H:%M:%S.%f"
+                "%y-%m-%d %H:%M:%S.%f"
             )
         else:
             dateTime = datetime.datetime.fromtimestamp(time.time()).strftime(
-                "%y-%M-%d %H:%M:%S"
+                "%y-%m-%d %H:%M:%S"
             )
         print("%s--%s--%s" % (dateTime, "INFO", message))
